@@ -4,7 +4,7 @@ from django.template.loader import render_to_string
 from django.
 register = template.Library()
 
-from ..lib.manager import NavigationManager
+from django_navigation_manager.lib.manager import NavigationManager
 
 navigation_manager = NavigationManager()
 template_path = "navigation_bar.html"
